Struct rsonpath_lib::error::UnsupportedFeatureError
source · pub struct UnsupportedFeatureError { /* private fields */ }Expand description
Error raised when rsonpath is asked to perform an operation that is currently unsupported. This may be either because the feature is in the works, or because it is not planned to ever be supported.