Module rsonpath_lib::quotes

source ·
Classification of bytes withing JSON quote sequences.

Provides the QuoteClassifiedBlock struct and QuoteClassifiedIterator trait that allow effectively enriching JSON inputs with quote sequence information.

Structs

Input block with a bitmask signifying which characters are within quotes.
State of the block at which classification was stopped.
State allowing resumption of a classifier from a particular place in the input along with the stopped QuoteClassifiedIterator.

Traits

Trait for quote classifier iterators, i.e. finite iterators enriching blocks of input with quote bitmasks. Iterator is allowed to hold a reference to the JSON document valid for 'a.

Functions

Walk through the JSON document represented by bytes and classify quoted sequences.