Struct rsonpath_lib::stackless::StacklessRunner
source · pub struct StacklessRunner<'q> { /* private fields */ }Expand description
Stackless runner for a fixed JSONPath query.
The runner is stateless, meaning that it can be executed on any number of separate inputs, even on separate threads.
Implementations
sourceimpl StacklessRunner<'_>
impl StacklessRunner<'_>
sourcepub fn compile_query(
query: &JsonPathQuery
) -> Result<StacklessRunner<'_>, CompilerError>
pub fn compile_query(
query: &JsonPathQuery
) -> Result<StacklessRunner<'_>, CompilerError>
Compile a query into a StacklessRunner.
Compilation time is proportional to the length of the query.
Errors
CompilerError may be raised by the Automaton when compiling the query.